@@ -16,7 +16,7 @@ class Distro(Module):
         url, dst = kw['url'], kw.get('dst')
         dst = dst or 'downloaded'
         try:
-            ret, out, err = target.run(f'http --download {url} -o {dst}')
+            ret, out, err = target.run(f'wget2 -q {url} -O {dst}')
             if ret!=0:
                 raise RuntimeError
         except:
@@ -26,12 +26,12 @@ class Distro(Module):
                     raise RuntimeError
             except:
                 try:
-                    ret, out, err = target.run(f'wget -q {url} -O {dst}')
+                    ret, out, err = target.run(f'http --download {url} -o {dst}')
                     if ret!=0:
                         raise RuntimeError
                 except:
-                    target.pip.install('httpie')
-                    ret, out, err = target.run(f'http --download {url} -o {dst}')
+                    target.Packag.install('curl')
+                    ret, out, err = target.run(f'curl -sfL {url} -o {dst}')
                     if ret!=0:
                         msg = err[0]
                         error(msg)
