@@ -1,24 +1,20 @@
 from setux.core import __version__
-from setux.logger import info
+from setux.logger import logger, info
 from setux.core.module import Module
 
 
 class Distro(Module):
-    '''Show infos
+    '''Show target infos
     '''
     def deploy(self, target, **kw):
         user = target.login.name
         kernel = target.kernel
         python = target.run('python3 -V')[1][0]
-        sys = target.distro.system
-        try:
-            addr = target.net.addr
-        except:
-            addr = '!'
-
-        inst = '-' #len(list(target.Package.installed()))
-        avail = '-' #len(list(target.Package.installable()))
-        #packages : {inst} / {avail}
+        with logger.quiet():
+            try:
+                addr = target.net.addr
+            except:
+                addr = '!'
 
         infos =  f'''
         target : {target}
@@ -26,7 +22,7 @@ class Distro(Module):
         python : {python}
         os     : {kernel.name} {kernel.version} / {kernel.arch}
         user   : {user}
-        host   : {sys.hostname} : {addr}
+        host   : {target.system.hostname} : {addr}
         setux  : {__version__}
         '''
 
