@@ -11,19 +11,18 @@ class Distro(Module):
         cont = target.read(cfg, report='quiet')
         if dst in cont: return True
         msg = [f'{cfg} <>']
-
         if src:
             sre = compile(src).search
-            updated, done = [], False
+            updated, found = [], False
             for line in cont.split('\n'):
                 if sre(line):
+                    found = True
                     msg.append(f' <  {line}')
                     msg.append(f'  > {dst}')
                     updated.append(dst)
-                    done = True
                 else:
                     updated.append(line)
-            if not done:
+            if not found:
                 updated.append(dst)
             target.write(cfg, '\n'.join(updated)+'\n', report='quiet')
         else:
